bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution.__init__
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialDistribution.__init__